@@ -25,6 +25,7 @@ module Yesod.AngularUI
     , addConfig
     , addConfigRaw
     , addService
+    , addRun
 
     , addFactoryStore
    -- ^ naive persistent store
@@ -33,6 +34,7 @@ module Yesod.AngularUI
     , addProvide
     , addFilter
     , addConstant
+    , addValue
    -- some normal stuff
     , addSetup
    -- ^ before the code, maybe some imports?
@@ -155,6 +157,13 @@ addConfig name' funcall = do
         #{rawJS n}.^{funcall}; }])|]
         }
 
+addRun :: (Monad m) => ((Route master -> [(Text, Text)] -> Text) -> Javascript)
+                       -> GAngular master m ()
+addRun funcall =
+    tell mempty
+        { awConfigs = [julius|.run(^{funcall})|]
+        }
+
 addConfigRaw :: (Monad m) => ((Route master -> [(Text, Text)] -> Text) -> Javascript)
                           -> GAngular master m ()
 addConfigRaw funcall = tell mempty { awConfigs = [julius|.config(^{funcall})|] }
@@ -231,6 +240,11 @@ addConstant :: (Monad m) => Text -> ((Route master -> [(Text, Text)] -> Text) ->
 -- ^ add constant, remember to quote if raw text
 addConstant n funcall = addProvide [julius|constant("#{rawJS n}",^{funcall})|]
 
+
+addValue :: (Monad m) => Text -> ((Route master -> [(Text, Text)] -> Text) -> Javascript) -> GAngular master m ()
+-- ^ add constant, remember to quote if raw text
+addValue n funcall = addProvide [julius|value("#{rawJS n}",^{funcall})|]
+
 addSetup :: (Monad m) => ((Route master -> [(Text, Text)] -> Text) -> Javascript)
                       -> GAngular master m ()
 -- ^ inject this code befor calling angular
@@ -285,8 +299,6 @@ addFactoryStore n = addFactory (n <> "Store") [julius| function(){
      }
     |]
 
-
-
 url :: Monad m => Text -> WriterT (UiState master) m ()
 url u = tell mempty {uisUrl  = Just u}
 
